==> portal-service-6.0.6-sources.jar: com/liferay/portlet/journal/model/JournalStructureConstants.java <==
/**
 * Copyright (c) 2000-2011 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portlet.journal.model;

/**
 * @author Alexander Chow
 */
public class JournalStructureConstants {

	public static final String RESERVED = "reserved";

	public static final String RESERVED_ARTICLE_ASSET_TAG_NAMES =
		"reserved-article-asset-tag-names";

	public static final String RESERVED_ARTICLE_AUTHOR_COMMENTS =
		"reserved-article-author-comments";

	public static final String RESERVED_ARTICLE_AUTHOR_EMAIL_ADDRESS =
		"reserved-article-author-email-address";

	public static final String RESERVED_ARTICLE_AUTHOR_ID =
		"reserved-article-author-id";

	public static final String RESERVED_ARTICLE_AUTHOR_JOB_TITLE =
		"reserved-article-author-job-title";

	public static final String RESERVED_ARTICLE_AUTHOR_LOCATION =
		"reserved-article-author-location";

	public static final String RESERVED_ARTICLE_AUTHOR_NAME =
		"reserved-article-author-name";

	public static final String RESERVED_ARTICLE_AUTHOR_ORGANIZATION =
		"reserved-article-author-organization";

	public static final String RESERVED_ARTICLE_CREATE_DATE =
		"reserved-article-create-date";

	public static final String RESERVED_ARTICLE_DESCRIPTION =
		"reserved-article-description";

	public static final String RESERVED_ARTICLE_DISPLAY_DATE =
		"reserved-article-display-date";

	public static final String RESERVED_ARTICLE_ID = "reserved-article-id";

	public static final String RESERVED_ARTICLE_MODIFIED_DATE =
		"reserved-article-modified-date";

	public static final String RESERVED_ARTICLE_SMALL_IMAGE_URL =
		"reserved-article-small-image-url";

	public static final String RESERVED_ARTICLE_TITLE =
		"reserved-article-title";

	public static final String RESERVED_ARTICLE_TYPE =
		"reserved-article-type";

	public static final String RESERVED_ARTICLE_URL_TITLE =
		"reserved-article-url-title";

	public static final String RESERVED_ARTICLE_VERSION =
		"reserved-article-version";

}

==> portal-service-6.1.1-sources.jar: com/liferay/portlet/journal/model/JournalStructureConstants.java <==
/**
 * Copyright (c) 2000-2012 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portlet.journal.model;

/**
 * @author Alexander Chow
 */
public class JournalStructureConstants {

	public static final String RESERVED = "reserved";

	public static final String RESERVED_ARTICLE_ASSET_TAG_NAMES =
		"reserved-article-asset-tag-names";

	public static final String RESERVED_ARTICLE_AUTHOR_COMMENTS =
		"reserved-article-author-comments";

	public static final String RESERVED_ARTICLE_AUTHOR_EMAIL_ADDRESS =
		"reserved-article-author-email-address";

	public static final String RESERVED_ARTICLE_AUTHOR_ID =
		"reserved-article-author-id";

	public static final String RESERVED_ARTICLE_AUTHOR_JOB_TITLE =
		"reserved-article-author-job-title";

	public static final String RESERVED_ARTICLE_AUTHOR_LOCATION =
		"reserved-article-author-location";

	public static final String RESERVED_ARTICLE_AUTHOR_NAME =
		"reserved-article-author-name";

	public static final String RESERVED_ARTICLE_AUTHOR_ORGANIZATION =
		"reserved-article-author-organization";

	public static final String RESERVED_ARTICLE_CREATE_DATE =
		"reserved-article-create-date";

	public static final String RESERVED_ARTICLE_DESCRIPTION =
		"reserved-article-description";

	public static final String RESERVED_ARTICLE_DISPLAY_DATE =
		"reserved-article-display-date";

	public static final String RESERVED_ARTICLE_ID = "reserved-article-id";

	public static final String RESERVED_ARTICLE_MODIFIED_DATE =
		"reserved-article-modified-date";

	public static final String RESERVED_ARTICLE_SMALL_IMAGE_URL =
		"reserved-article-small-image-url";

	public static final String RESERVED_ARTICLE_TITLE =
		"reserved-article-title";

	public static final String RESERVED_ARTICLE_TYPE = "reserved-article-type";

	public static final String RESERVED_ARTICLE_URL_TITLE =
		"reserved-article-url-title";

	public static final String RESERVED_ARTICLE_VERSION =
		"reserved-article-version";

}
